@@ -13,6 +13,8 @@ class QolsysTableQolsysSettings(QolsysTable):
         self._uri = "content://com.qolsys.qolsysprovider.QolsysSettingsProvider/qolsyssettings"
         self._table = "qolsyssettings"
         self._abort_on_error = True
+        self._implemented = True
+
 
         self._columns = [
             "_id",
@@ -24,14 +26,3 @@ class QolsysTableQolsysSettings(QolsysTable):
         ]
 
         self._create_table()
-
-    def insert(self, data: dict) -> None:
-        self._cursor.execute(f"INSERT INTO {self.table} (_id,version,opr,partition_id,name,value) VALUES (?,?,?,?,?,?)", (
-            data.get("_id"),
-            data.get("version", ""),
-            data.get("opr", ""),
-            data.get("partition_id", ""),
-            data.get("name", ""),
-            data.get("value", "")))
-
-        self._db.commit()
